==> appsync-2.30.0-sources.jar: software/amazon/awssdk/services/appsync/model/ApiKey.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.appsync.model;

import java.io.Serializable;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.Optional;
import java.util.function.BiConsumer;
import java.util.function.Function;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.SdkField;
import software.amazon.awssdk.core.SdkPojo;
import software.amazon.awssdk.core.protocol.MarshallLocation;
import software.amazon.awssdk.core.protocol.MarshallingType;
import software.amazon.awssdk.core.traits.LocationTrait;
import software.amazon.awssdk.utils.ToString;
import software.amazon.awssdk.utils.builder.CopyableBuilder;
import software.amazon.awssdk.utils.builder.ToCopyableBuilder;

/**
 * <p>
 * Describes an API key.
 * </p>
 * <p>
 * Customers invoke AppSync GraphQL API operations with API keys as an identity mechanism. There are two key versions:
 * </p>
 * <p>
 * <b>da1</b>: We introduced this version at launch in November 2017. These keys always expire after 7 days. Amazon
 * DynamoDB TTL manages key expiration. These keys ceased to be valid after February 21, 2018, and they should no longer
 * be used.
 * </p>
 * <ul>
 * <li>
 * <p>
 * <code>ListApiKeys</code> returns the expiration time in milliseconds.
 * </p>
 * </li>
 * <li>
 * <p>
 * <code>CreateApiKey</code> returns the expiration time in milliseconds.
 * </p>
 * </li>
 * <li>
 * <p>
 * <code>UpdateApiKey</code> is not available for this key version.
 * </p>
 * </li>
 * <li>
 * <p>
 * <code>DeleteApiKey</code> deletes the item from the table.
 * </p>
 * </li>
 * <li>
 * <p>
 * Expiration is stored in DynamoDB as milliseconds. This results in a bug where keys are not automatically deleted
 * because DynamoDB expects the TTL to be stored in seconds. As a one-time action, we deleted these keys from the table
 * on February 21, 2018.
 * </p>
 * </li>
 * </ul>
 * <p>
 * <b>da2</b>: We introduced this version in February 2018 when AppSync added support to extend key expiration.
 * </p>
 * <ul>
 * <li>
 * <p>
 * <code>ListApiKeys</code> returns the expiration time and deletion time in seconds.
 * </p>
 * </li>
 * <li>
 * <p>
 * <code>CreateApiKey</code> returns the expiration time and deletion time in seconds and accepts a user-provided
 * expiration time in seconds.
 * </p>
 * </li>
 * <li>
 * <p>
 * <code>UpdateApiKey</code> returns the expiration time and and deletion time in seconds and accepts a user-provided
 * expiration time in seconds. Expired API keys are kept for 60 days after the expiration time. You can update the key
 * expiration time as long as the key isn't deleted.
 * </p>
 * </li>
 * <li>
 * <p>
 * <code>DeleteApiKey</code> deletes the item from the table.
 * </p>
 * </li>
 * <li>
 * <p>
 * Expiration is stored in DynamoDB as seconds. After the expiration time, using the key to authenticate will fail.
 * However, you can reinstate the key before deletion.
 * </p>
 * </li>
 * <li>
 * <p>
 * Deletion is stored in DynamoDB as seconds. The key is deleted after deletion time.
 * </p>
 * </li>
 * </ul>
 */
@Generated("software.amazon.awssdk:codegen")
public final class ApiKey implements SdkPojo, Serializable, ToCopyableBuilder<ApiKey.Builder, ApiKey> {
    private static final SdkField<String> ID_FIELD = SdkField.<String> builder(MarshallingType.STRING).memberName("id")
            .getter(getter(ApiKey::id)).setter(setter(Builder::id))
            .traits(LocationTrait.builder().location(MarshallLocation.PAYLOAD).locationName("id").build()).build();

    private static final SdkField<String> DESCRIPTION_FIELD = SdkField.<String> builder(MarshallingType.STRING)
            .memberName("description").getter(getter(ApiKey::description)).setter(setter(Builder::description))
            .traits(LocationTrait.builder().location(MarshallLocation.PAYLOAD).locationName("description").build()).build();

    private static final SdkField<Long> EXPIRES_FIELD = SdkField.<Long> builder(MarshallingType.LONG).memberName("expires")
            .getter(getter(ApiKey::expires)).setter(setter(Builder::expires))
            .traits(LocationTrait.builder().location(MarshallLocation.PAYLOAD).locationName("expires").build()).build();

    private static final SdkField<Long> DELETES_FIELD = SdkField.<Long> builder(MarshallingType.LONG).memberName("deletes")
            .getter(getter(ApiKey::deletes)).setter(setter(Builder::deletes))
            .traits(LocationTrait.builder().location(MarshallLocation.PAYLOAD).locationName("deletes").build()).build();

    private static final List<SdkField<?>> SDK_FIELDS = Collections.unmodifiableList(Arrays.asList(ID_FIELD, DESCRIPTION_FIELD,
            EXPIRES_FIELD, DELETES_FIELD));

    private static final Map<String, SdkField<?>> SDK_NAME_TO_FIELD = memberNameToFieldInitializer();

    private static final long serialVersionUID = 1L;

    private final String id;

    private final String description;

    private final Long expires;

    private final Long deletes;

    private ApiKey(BuilderImpl builder) {
        this.id = builder.id;
        this.description = builder.description;
        this.expires = builder.expires;
        this.deletes = builder.deletes;
    }

    /**
     * <p>
     * The API key ID.
     * </p>
     * 
     * @return The API key ID.
     */
    public final String id() {
        return id;
    }

    /**
     * <p>
     * A description of the purpose of the API key.
     * </p>
     * 
     * @return A description of the purpose of the API key.
     */
    public final String description() {
        return description;
    }

    /**
     * <p>
     * The time after which the API key expires. The date is represented as seconds since the epoch, rounded down to the
     * nearest hour.
     * </p>
     * 
     * @return The time after which the API key expires. The date is represented as seconds since the epoch, rounded
     *         down to the nearest hour.
     */
    public final Long expires() {
        return expires;
    }

    /**
     * <p>
     * The time after which the API key is deleted. The date is represented as seconds since the epoch, rounded down to
     * the nearest hour.
     * </p>
     * 
     * @return The time after which the API key is deleted. The date is represented as seconds since the epoch, rounded
     *         down to the nearest hour.
     */
    public final Long deletes() {
        return deletes;
    }

    @Override
    public Builder toBuilder() {
        return new BuilderImpl(this);
    }

    public static Builder builder() {
        return new BuilderImpl();
    }

    public static Class<? extends Builder> serializableBuilderClass() {
        return BuilderImpl.class;
    }

    @Override
    public final int hashCode() {
        int hashCode = 1;
        hashCode = 31 * hashCode + Objects.hashCode(id());
        hashCode = 31 * hashCode + Objects.hashCode(description());
        hashCode = 31 * hashCode + Objects.hashCode(expires());
        hashCode = 31 * hashCode + Objects.hashCode(deletes());
        return hashCode;
    }

    @Override
    public final boolean equals(Object obj) {
        return equalsBySdkFields(obj);
    }

    @Override
    public final boolean equalsBySdkFields(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (!(obj instanceof ApiKey)) {
            return false;
        }
        ApiKey other = (ApiKey) obj;
        return Objects.equals(id(), other.id()) && Objects.equals(description(), other.description())
                && Objects.equals(expires(), other.expires()) && Objects.equals(deletes(), other.deletes());
    }

    /**
     * Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be
     * redacted from this string using a placeholder value.
     */
    @Override
    public final String toString() {
        return ToString.builder("ApiKey").add("Id", id()).add("Description", description()).add("Expires", expires())
                .add("Deletes", deletes()).build();
    }

    public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz) {
        switch (fieldName) {
        case "id":
            return Optional.ofNullable(clazz.cast(id()));
        case "description":
            return Optional.ofNullable(clazz.cast(description()));
        case "expires":
            return Optional.ofNullable(clazz.cast(expires()));
        case "deletes":
            return Optional.ofNullable(clazz.cast(deletes()));
        default:
            return Optional.empty();
        }
    }

    @Override
    public final List<SdkField<?>> sdkFields() {
        return SDK_FIELDS;
    }

    @Override
    public final Map<String, SdkField<?>> sdkFieldNameToField() {
        return SDK_NAME_TO_FIELD;
    }

    private static Map<String, SdkField<?>> memberNameToFieldInitializer() {
        Map<String, SdkField<?>> map = new HashMap<>();
        map.put("id", ID_FIELD);
        map.put("description", DESCRIPTION_FIELD);
        map.put("expires", EXPIRES_FIELD);
        map.put("deletes", DELETES_FIELD);
        return Collections.unmodifiableMap(map);
    }

    private static <T> Function<Object, T> getter(Function<ApiKey, T> g) {
        return obj -> g.apply((ApiKey) obj);
    }

    private static <T> BiConsumer<Object, T> setter(BiConsumer<Builder, T> s) {
        return (obj, val) -> s.accept((Builder) obj, val);
    }

    public interface Builder extends SdkPojo, CopyableBuilder<Builder, ApiKey> {
        /**
         * <p>
         * The API key ID.
         * </p>
         * 
         * @param id
         *        The API key ID.
         * @return Returns a reference to this object so that method calls can be chained together.
         */
        Builder id(String id);

        /**
         * <p>
         * A description of the purpose of the API key.
         * </p>
         * 
         * @param description
         *        A description of the purpose of the API key.
         * @return Returns a reference to this object so that method calls can be chained together.
         */
        Builder description(String description);

        /**
         * <p>
         * The time after which the API key expires. The date is represented as seconds since the epoch, rounded down to
         * the nearest hour.
         * </p>
         * 
         * @param expires
         *        The time after which the API key expires. The date is represented as seconds since the epoch, rounded
         *        down to the nearest hour.
         * @return Returns a reference to this object so that method calls can be chained together.
         */
        Builder expires(Long expires);

        /**
         * <p>
         * The time after which the API key is deleted. The date is represented as seconds since the epoch, rounded down
         * to the nearest hour.
         * </p>
         * 
         * @param deletes
         *        The time after which the API key is deleted. The date is represented as seconds since the epoch,
         *        rounded down to the nearest hour.
         * @return Returns a reference to this object so that method calls can be chained together.
         */
        Builder deletes(Long deletes);
    }

    static final class BuilderImpl implements Builder {
        private String id;

        private String description;

        private Long expires;

        private Long deletes;

        private BuilderImpl() {
        }

        private BuilderImpl(ApiKey model) {
            id(model.id);
            description(model.description);
            expires(model.expires);
            deletes(model.deletes);
        }

        public final String getId() {
            return id;
        }

        public final void setId(String id) {
            this.id = id;
        }

        @Override
        public final Builder id(String id) {
            this.id = id;
            return this;
        }

        public final String getDescription() {
            return description;
        }

        public final void setDescription(String description) {
            this.description = description;
        }

        @Override
        public final Builder description(String description) {
            this.description = description;
            return this;
        }

        public final Long getExpires() {
            return expires;
        }

        public final void setExpires(Long expires) {
            this.expires = expires;
        }

        @Override
        public final Builder expires(Long expires) {
            this.expires = expires;
            return this;
        }

        public final Long getDeletes() {
            return deletes;
        }

        public final void setDeletes(Long deletes) {
            this.deletes = deletes;
        }

        @Override
        public final Builder deletes(Long deletes) {
            this.deletes = deletes;
            return this;
        }

        @Override
        public ApiKey build() {
            return new ApiKey(this);
        }

        @Override
        public List<SdkField<?>> sdkFields() {
            return SDK_FIELDS;
        }

        @Override
        public Map<String, SdkField<?>> sdkFieldNameToField() {
            return SDK_NAME_TO_FIELD;
        }
    }
}

==> appsync-2.33.6-sources.jar: software/amazon/awssdk/services/appsync/model/ApiKey.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.appsync.model;

import java.io.Serializable;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.Optional;
import java.util.function.BiConsumer;
import java.util.function.Function;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.annotations.Mutable;
import software.amazon.awssdk.annotations.NotThreadSafe;
import software.amazon.awssdk.core.SdkField;
import software.amazon.awssdk.core.SdkPojo;
import software.amazon.awssdk.core.protocol.MarshallLocation;
import software.amazon.awssdk.core.protocol.MarshallingType;
import software.amazon.awssdk.core.traits.LocationTrait;
import software.amazon.awssdk.utils.ToString;
import software.amazon.awssdk.utils.builder.CopyableBuilder;
import software.amazon.awssdk.utils.builder.ToCopyableBuilder;

/**
 * <p>
 * Describes an API key.
 * </p>
 * <p>
 * Customers invoke AppSync GraphQL API operations with API keys as an identity mechanism. There are two key versions:
 * </p>
 * <p>
 * <b>da1</b>: We introduced this version at launch in November 2017. These keys always expire after 7 days. Amazon
 * DynamoDB TTL manages key expiration. These keys ceased to be valid after February 21, 2018, and they should no longer
 * be used.
 * </p>
 * <ul>
 * <li>
 * <p>
 * <code>ListApiKeys</code> returns the expiration time in milliseconds.
 * </p>
 * </li>
 * <li>
 * <p>
 * <code>CreateApiKey</code> returns the expiration time in milliseconds.
 * </p>
 * </li>
 * <li>
 * <p>
 * <code>UpdateApiKey</code> is not available for this key version.
 * </p>
 * </li>
 * <li>
 * <p>
 * <code>DeleteApiKey</code> deletes the item from the table.
 * </p>
 * </li>
 * <li>
 * <p>
 * Expiration is stored in DynamoDB as milliseconds. This results in a bug where keys are not automatically deleted
 * because DynamoDB expects the TTL to be stored in seconds. As a one-time action, we deleted these keys from the table
 * on February 21, 2018.
 * </p>
 * </li>
 * </ul>
 * <p>
 * <b>da2</b>: We introduced this version in February 2018 when AppSync added support to extend key expiration.
 * </p>
 * <ul>
 * <li>
 * <p>
 * <code>ListApiKeys</code> returns the expiration time and deletion time in seconds.
 * </p>
 * </li>
 * <li>
 * <p>
 * <code>CreateApiKey</code> returns the expiration time and deletion time in seconds and accepts a user-provided
 * expiration time in seconds.
 * </p>
 * </li>
 * <li>
 * <p>
 * <code>UpdateApiKey</code> returns the expiration time and and deletion time in seconds and accepts a user-provided
 * expiration time in seconds. Expired API keys are kept for 60 days after the expiration time. You can update the key
 * expiration time as long as the key isn't deleted.
 * </p>
 * </li>
 * <li>
 * <p>
 * <code>DeleteApiKey</code> deletes the item from the table.
 * </p>
 * </li>
 * <li>
 * <p>
 * Expiration is stored in DynamoDB as seconds. After the expiration time, using the key to authenticate will fail.
 * However, you can reinstate the key before deletion.
 * </p>
 * </li>
 * <li>
 * <p>
 * Deletion is stored in DynamoDB as seconds. The key is deleted after deletion time.
 * </p>
 * </li>
 * </ul>
 */
@Generated("software.amazon.awssdk:codegen")
public final class ApiKey implements SdkPojo, Serializable, ToCopyableBuilder<ApiKey.Builder, ApiKey> {
    private static final SdkField<String> ID_FIELD = SdkField.<String> builder(MarshallingType.STRING).memberName("id")
            .getter(getter(ApiKey::id)).setter(setter(Builder::id))
            .traits(LocationTrait.builder().location(MarshallLocation.PAYLOAD).locationName("id").build()).build();

    private static final SdkField<String> DESCRIPTION_FIELD = SdkField.<String> builder(MarshallingType.STRING)
            .memberName("description").getter(getter(ApiKey::description)).setter(setter(Builder::description))
            .traits(LocationTrait.builder().location(MarshallLocation.PAYLOAD).locationName("description").build()).build();

    private static final SdkField<Long> EXPIRES_FIELD = SdkField.<Long> builder(MarshallingType.LONG).memberName("expires")
            .getter(getter(ApiKey::expires)).setter(setter(Builder::expires))
            .traits(LocationTrait.builder().location(MarshallLocation.PAYLOAD).locationName("expires").build()).build();

    private static final SdkField<Long> DELETES_FIELD = SdkField.<Long> builder(MarshallingType.LONG).memberName("deletes")
            .getter(getter(ApiKey::deletes)).setter(setter(Builder::deletes))
            .traits(LocationTrait.builder().location(MarshallLocation.PAYLOAD).locationName("deletes").build()).build();

    private static final List<SdkField<?>> SDK_FIELDS = Collections.unmodifiableList(Arrays.asList(ID_FIELD, DESCRIPTION_FIELD,
            EXPIRES_FIELD, DELETES_FIELD));

    private static final Map<String, SdkField<?>> SDK_NAME_TO_FIELD = memberNameToFieldInitializer();

    private static final long serialVersionUID = 1L;

    private final String id;

    private final String description;

    private final Long expires;

    private final Long deletes;

    private ApiKey(BuilderImpl builder) {
        this.id = builder.id;
        this.description = builder.description;
        this.expires = builder.expires;
        this.deletes = builder.deletes;
    }

    /**
     * <p>
     * The API key ID.
     * </p>
     * 
     * @return The API key ID.
     */
    public final String id() {
        return id;
    }

    /**
     * <p>
     * A description of the purpose of the API key.
     * </p>
     * 
     * @return A description of the purpose of the API key.
     */
    public final String description() {
        return description;
    }

    /**
     * <p>
     * The time after which the API key expires. The date is represented as seconds since the epoch, rounded down to the
     * nearest hour.
     * </p>
     * 
     * @return The time after which the API key expires. The date is represented as seconds since the epoch, rounded
     *         down to the nearest hour.
     */
    public final Long expires() {
        return expires;
    }

    /**
     * <p>
     * The time after which the API key is deleted. The date is represented as seconds since the epoch, rounded down to
     * the nearest hour.
     * </p>
     * 
     * @return The time after which the API key is deleted. The date is represented as seconds since the epoch, rounded
     *         down to the nearest hour.
     */
    public final Long deletes() {
        return deletes;
    }

    @Override
    public Builder toBuilder() {
        return new BuilderImpl(this);
    }

    public static Builder builder() {
        return new BuilderImpl();
    }

    public static Class<? extends Builder> serializableBuilderClass() {
        return BuilderImpl.class;
    }

    @Override
    public final int hashCode() {
        int hashCode = 1;
        hashCode = 31 * hashCode + Objects.hashCode(id());
        hashCode = 31 * hashCode + Objects.hashCode(description());
        hashCode = 31 * hashCode + Objects.hashCode(expires());
        hashCode = 31 * hashCode + Objects.hashCode(deletes());
        return hashCode;
    }

    @Override
    public final boolean equals(Object obj) {
        return equalsBySdkFields(obj);
    }

    @Override
    public final boolean equalsBySdkFields(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (!(obj instanceof ApiKey)) {
            return false;
        }
        ApiKey other = (ApiKey) obj;
        return Objects.equals(id(), other.id()) && Objects.equals(description(), other.description())
                && Objects.equals(expires(), other.expires()) && Objects.equals(deletes(), other.deletes());
    }

    /**
     * Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be
     * redacted from this string using a placeholder value.
     */
    @Override
    public final String toString() {
        return ToString.builder("ApiKey").add("Id", id()).add("Description", description()).add("Expires", expires())
                .add("Deletes", deletes()).build();
    }

    public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz) {
        switch (fieldName) {
        case "id":
            return Optional.ofNullable(clazz.cast(id()));
        case "description":
            return Optional.ofNullable(clazz.cast(description()));
        case "expires":
            return Optional.ofNullable(clazz.cast(expires()));
        case "deletes":
            return Optional.ofNullable(clazz.cast(deletes()));
        default:
            return Optional.empty();
        }
    }

    @Override
    public final List<SdkField<?>> sdkFields() {
        return SDK_FIELDS;
    }

    @Override
    public final Map<String, SdkField<?>> sdkFieldNameToField() {
        return SDK_NAME_TO_FIELD;
    }

    private static Map<String, SdkField<?>> memberNameToFieldInitializer() {
        Map<String, SdkField<?>> map = new HashMap<>();
        map.put("id", ID_FIELD);
        map.put("description", DESCRIPTION_FIELD);
        map.put("expires", EXPIRES_FIELD);
        map.put("deletes", DELETES_FIELD);
        return Collections.unmodifiableMap(map);
    }

    private static <T> Function<Object, T> getter(Function<ApiKey, T> g) {
        return obj -> g.apply((ApiKey) obj);
    }

    private static <T> BiConsumer<Object, T> setter(BiConsumer<Builder, T> s) {
        return (obj, val) -> s.accept((Builder) obj, val);
    }

    @Mutable
    @NotThreadSafe
    public interface Builder extends SdkPojo, CopyableBuilder<Builder, ApiKey> {
        /**
         * <p>
         * The API key ID.
         * </p>
         * 
         * @param id
         *        The API key ID.
         * @return Returns a reference to this object so that method calls can be chained together.
         */
        Builder id(String id);

        /**
         * <p>
         * A description of the purpose of the API key.
         * </p>
         * 
         * @param description
         *        A description of the purpose of the API key.
         * @return Returns a reference to this object so that method calls can be chained together.
         */
        Builder description(String description);

        /**
         * <p>
         * The time after which the API key expires. The date is represented as seconds since the epoch, rounded down to
         * the nearest hour.
         * </p>
         * 
         * @param expires
         *        The time after which the API key expires. The date is represented as seconds since the epoch, rounded
         *        down to the nearest hour.
         * @return Returns a reference to this object so that method calls can be chained together.
         */
        Builder expires(Long expires);

        /**
         * <p>
         * The time after which the API key is deleted. The date is represented as seconds since the epoch, rounded down
         * to the nearest hour.
         * </p>
         * 
         * @param deletes
         *        The time after which the API key is deleted. The date is represented as seconds since the epoch,
         *        rounded down to the nearest hour.
         * @return Returns a reference to this object so that method calls can be chained together.
         */
        Builder deletes(Long deletes);
    }

    static final class BuilderImpl implements Builder {
        private String id;

        private String description;

        private Long expires;

        private Long deletes;

        private BuilderImpl() {
        }

        private BuilderImpl(ApiKey model) {
            id(model.id);
            description(model.description);
            expires(model.expires);
            deletes(model.deletes);
        }

        public final String getId() {
            return id;
        }

        public final void setId(String id) {
            this.id = id;
        }

        @Override
        public final Builder id(String id) {
            this.id = id;
            return this;
        }

        public final String getDescription() {
            return description;
        }

        public final void setDescription(String description) {
            this.description = description;
        }

        @Override
        public final Builder description(String description) {
            this.description = description;
            return this;
        }

        public final Long getExpires() {
            return expires;
        }

        public final void setExpires(Long expires) {
            this.expires = expires;
        }

        @Override
        public final Builder expires(Long expires) {
            this.expires = expires;
            return this;
        }

        public final Long getDeletes() {
            return deletes;
        }

        public final void setDeletes(Long deletes) {
            this.deletes = deletes;
        }

        @Override
        public final Builder deletes(Long deletes) {
            this.deletes = deletes;
            return this;
        }

        @Override
        public ApiKey build() {
            return new ApiKey(this);
        }

        @Override
        public List<SdkField<?>> sdkFields() {
            return SDK_FIELDS;
        }

        @Override
        public Map<String, SdkField<?>> sdkFieldNameToField() {
            return SDK_NAME_TO_FIELD;
        }
    }
}
